# AiiDA-DFTK Plugin

## Overview

This is an [AiiDA](https://www.aiida.net/) plugin
for [DFTK](https://docs.dftk.org/stable/),
providing support from the AiiDA side to integrate DFTK seamlessly.

**Note:** For complete integration of DFTK with the AiiDA ecosystem,
the [AiidaDFTK](https://github.com/mfherbst/AiidaDFTK.jl) plugin
is also required for the Julia side.
See the [setup documentation](docs/source/1-setup.md).

## Documentation
There are four documentation files available to guide you through the setup
and usage of the AiiDA-DFTK plugin:

1. [**Set-up:**](docs/source/1-setup.md)
   Learn how to set up the AiiDA-DFTK plugin.
2. [**Calculations:**](docs/source/2-calculation.md)
   Discover how to run DFTK calculations using AiiDA.
3. [**Common Workflow:**](docs/source/3-common-workflow.md)
   Explore how to run a DFTK calculation using AiiDA's common workflow system.

## Contact
AiiDA-DFTK is currently maintained by:
- **Bruno Ploumhans**: bruno.ploumhans@epfl.ch

Former authors:
- **Yihan Wu**: yihan.wu@epfl.ch
- **Austin Zadoks**: austin.zadoks@epfl.ch
